==> roundcubemail-1.2.5-1-any.pkg.tar.xz: usr/share/webapps/roundcubemail/program/js/tinymce/langs/tr_TR.js <==
tinymce.addI18n('tr_TR',{
"Cut": "Kes",
"Heading 5": "Ba\u015fl\u0131k 5",
"Header 2": "Ba\u015fl\u0131k 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Taray\u0131c\u0131n\u0131z panoya direk eri\u015fimi desteklemiyor. L\u00fctfen Ctrl+X\/C\/V klavye k\u0131sayollar\u0131n\u0131 kullan\u0131n.",
"Heading 4": "Ba\u015fl\u0131k 4",
"Div": "Div",
"Heading 2": "Ba\u015fl\u0131k 2",
"Paste": "Yap\u0131\u015ft\u0131r",
"Close": "Kapat",
"Font Family": "Yaz\u0131tipi Ailesi",
"Pre": "\u00d6n",
"Align right": "Sa\u011fa hizala",
"New document": "Yeni dok\u00fcman",
"Blockquote": "Al\u0131nt\u0131",
"Numbered list": "S\u0131ral\u0131 liste",
"Heading 1": "Ba\u015fl\u0131k 1",
"Headings": "Ba\u015fl\u0131klar",
"Increase indent": "Girintiyi art\u0131r",
"Formats": "Bi\u00e7imler",
"Headers": "Ba\u015fl\u0131klar",
"Select all": "T\u00fcm\u00fcn\u00fc se\u00e7",
"Header 3": "Ba\u015fl\u0131k 3",
"Blocks": "Bloklar",
"Undo": "Geri Al",
"Strikethrough": "\u00dcst\u00fc \u00e7izili",
"Bullet list": "S\u0131ras\u0131z liste",
"Header 1": "Ba\u015fl\u0131k 1",
"Superscript": "\u00dcst simge",
"Clear formatting": "Bi\u00e7imi temizle",
"Font Sizes": "Yaz\u0131tipi B\u00fcy\u00fckl\u00fc\u011f\u00fc",
"Subscript": "Alt simge",
"Header 6": "Ba\u015fl\u0131k 6",
"Redo": "Yinele",
"Paragraph": "Paragraf",
"Ok": "Tamam",
"Bold": "Kal\u0131n",
"Code": "Kod",
"Italic": "\u0130talik",
"Align center": "Ortala",
"Header 5": "Ba\u015fl\u0131k 5",
"Heading 6": "Ba\u015fl\u0131k 6",
"Heading 3": "Ba\u015fl\u0131k 3",
"Decrease indent": "Girintiyi azalt",
"Header 4": "Ba\u015fl\u0131k 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "D\u00fcz metin modunda yap\u0131\u015ft\u0131r. Bu se\u00e7ene\u011fi kapatana kadar i\u00e7erikler d\u00fcz metin olarak yap\u0131\u015ft\u0131r\u0131l\u0131r.",
"Underline": "Alt\u0131 \u00e7izili",
"Cancel": "\u0130ptal",
"Justify": "\u0130ki yana yasla",
"Inline": "Sat\u0131r i\u00e7i",
"Copy": "Kopyala",
"Align left": "Sola hizala",
"Visual aids": "G\u00f6rsel ara\u00e7lar",
"Lower Greek": "K\u00fc\u00e7\u00fck Yunan alfabesi",
"Square": "Kare",
"Default": "Varsay\u0131lan",
"Lower Alpha": "K\u00fc\u00e7\u00fck ABC",
"Circle": "Daire",
"Disc": "Disk",
"Upper Alpha": "B\u00fcy\u00fck ABC",
"Upper Roman": "B\u00fcy\u00fck Roman alfabesi",
"Lower Roman": "K\u00fc\u00e7\u00fck Roman alfabesi",
"Name": "\u0130sim",
"Anchor": "\u00c7apa",
"You have unsaved changes are you sure you want to navigate away?": "Kaydedilmemi\u015f de\u011fi\u015fiklikler var, sayfadan ayr\u0131lmak istedi\u011finize emin misiniz?",
"Restore last draft": "Son tasla\u011f\u0131 kurtar",
"Special character": "\u00d6zel karakter",
"Source code": "Kaynak kodu",
"B": "B",
"R": "R",
"G": "G",
"Color": "Renk",
"Right to left": "Sa\u011fdan sola",
"Left to right": "Soldan sa\u011fa",
"Emoticons": "G\u00fcl\u00fcc\u00fckler",
"Robots": "Robotlar",
"Document properties": "Dok\u00fcman \u00f6zellikleri",
"Title": "Ba\u015fl\u0131k",
"Keywords": "Anahtar kelimeler",
"Encoding": "Kodlama",
"Description": "A\u00e7\u0131klama",
"Author": "Yazar",
"Fullscreen": "Tam ekran",
"Horizontal line": "Yatay \u00e7izgi",
"Horizontal space": "Yatay bo\u015fluk",
"Insert\/edit image": "Resim ekle\/d\u00fczenle",
"General": "Genel",
"Advanced": "Geli\u015fmi\u015f",
"Source": "Kaynak",
"Border": "\u00c7er\u00e7eve",
"Constrain proportions": "En - Boy oran\u0131n\u0131 koru",
"Vertical space": "Dikey bo\u015fluk",
"Image description": "Resim a\u00e7\u0131klamas\u0131",
"Style": "Stil",
"Dimensions": "Boyutlar",
"Insert image": "Resim ekle",
"Insert date\/time": "Tarih \/ Zaman ekle",
"Remove link": "Ba\u011flant\u0131y\u0131 kald\u0131r",
"Url": "Url",
"Text to display": "G\u00f6r\u00fcnen yaz\u0131",
"Anchors": "\u00c7apalar",
"Insert link": "Ba\u011flant\u0131 ekle",
"New window": "Yeni pencere",
"None": "Hi\u00e7biri",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Girdi\u011finiz URL bir d\u0131\u015f ba\u011flant\u0131 gibi g\u00f6z\u00fck\u00fcyor. Gerekli olan http:\/\/ \u00f6nekini eklemek ister misiniz?",
"Target": "Hedef",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Girdi\u011finiz URL bir eposta adresi gibi g\u00f6z\u00fck\u00fcyor. Gerekli olan mailto: \u00f6nekini eklemek ister misiniz?",
"Insert\/edit link": "Ba\u011flant\u0131 ekle\/d\u00fczenle",
"Insert\/edit video": "Video ekle\/d\u00fczenle",
"Poster": "Poster",
"Alternative source": "Alternatif kaynak",
"Paste your embed code below:": "Medya g\u00f6mme kodunu buraya yap\u0131\u015ft\u0131r:",
"Insert video": "Video ekle",
"Embed": "G\u00f6mme",
"Nonbreaking space": "B\u00f6l\u00fcnemez bo\u015fluk",
"Page break": "Sayfa sonu",
"Paste as text": "Metin olarak yap\u0131\u015ft\u0131r",
"Preview": "\u00d6nizleme",
"Print": "Yazd\u0131r",
"Save": "Kaydet",
"Could not find the specified string.": "Herhangi bir sonu\u00e7 bulunamad\u0131.",
"Replace": "De\u011fi\u015ftir",
"Next": "Sonraki",
"Whole words": "Tam s\u00f6zc\u00fckler",
"Find and replace": "Bul ve de\u011fi\u015ftir",
"Replace with": "Bununla de\u011fi\u015ftir",
"Find": "Bul",
"Replace all": "T\u00fcm\u00fcn\u00fc de\u011fi\u015ftir",
"Match case": "B\u00fcy\u00fck \/ K\u00fc\u00e7\u00fck harfe duyarl\u0131",
"Prev": "\u00d6nceki",
"Spellcheck": "Yaz\u0131m denetimi",
"Finish": "Bitir",
"Ignore all": "T\u00fcm\u00fcn\u00fc yoksay",
"Ignore": "Yoksay",
"Add to Dictionary": "S\u00f6zl\u00fc\u011fe ekle",
"Insert row before": "\u00d6ncesine yeni sat\u0131r ekle",
"Rows": "Sat\u0131rlar",
"Height": "Y\u00fckseklik",
"Paste row after": "Sonras\u0131na sat\u0131r  yap\u0131\u015ft\u0131r",
"Alignment": "Hizalama",
"Border color": "Kenarl\u0131k Rengi",
"Column group": "S\u00fctun grubu",
"Row": "Sat\u0131r",
"Insert column before": "\u00d6ncesine yeni s\u00fctun ekle",
"Split cell": "H\u00fccreleri ay\u0131r",
"Cell padding": "H\u00fccre i\u00e7 bo\u015flu\u011fu",
"Cell spacing": "H\u00fccre aral\u0131\u011f\u0131",
"Row type": "Sat\u0131r tipi",
"Insert table": "Tablo ekle",
"Body": "G\u00f6vde",
"Caption": "Ba\u015fl\u0131k",
"Footer": "Alt",
"Delete row": "Sat\u0131r\u0131 sil",
"Paste row before": "\u00d6ncesine sat\u0131r yap\u0131\u015ft\u0131r",
"Scope": "Kapsam",
"Delete table": "Tabloyu sil",
"H Align": "Yatay Hizalama",
"Top": "\u00dcst",
"Header cell": "Ba\u015fl\u0131k h\u00fccresi",
"Column": "S\u00fctun",
"Row group": "Sat\u0131r grubu",
"Cell": "H\u00fccre",
"Middle": "Orta",
"Cell type": "H\u00fccre tipi",
"Copy row": "Sat\u0131r\u0131 kopyala",
"Row properties": "Sat\u0131r \u00f6zellikleri",
"Table properties": "Tablo \u00f6zellikleri",
"Bottom": "Alt",
"V Align": "Dikey Hizalama",
"Header": "Ba\u015fl\u0131k",
"Right": "Sa\u011f",
"Insert column after": "Sonras\u0131na yeni s\u00fctun ekle",
"Cols": "S\u00fctunlar",
"Insert row after": "Sonras\u0131na yeni sat\u0131r ekle",
"Width": "Geni\u015flik",
"Cell properties": "H\u00fccre \u00f6zellikleri",
"Left": "Sol",
"Cut row": "Sat\u0131r\u0131 kes",
"Delete column": "S\u00fctunu sil",
"Center": "Orta",
"Merge cells": "H\u00fccreleri birle\u015ftir",
"Insert template": "\u015eablon ekle",
"Templates": "\u015eablonlar",
"Background color": "Arkaplan rengi",
"Custom...": "\u00d6zel",
"Custom color": "\u00d6zel Renk",
"No color": "Renk Yok",
"Text color": "Yaz\u0131 rengi",
"Show blocks": "Bloklar\u0131 g\u00f6r\u00fcnt\u00fcle",
"Show invisible characters": "G\u00f6r\u00fcnmez karakterleri g\u00f6ster",
"Words: {0}": "Kelime: {0}",
"Insert": "Ekle",
"File": "Dosya",
"Edit": "D\u00fczenle",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Zengin Metin Alan\u0131. Men\u00fc i\u00e7in ALT-F9 k\u0131sayolunu kullan\u0131n. Ara\u00e7 \u00e7ubu\u011fu i\u00e7in ALT-F10 k\u0131sayolunu kullan\u0131n. Yard\u0131m i\u00e7in ALT-0 k\u0131sayolunu kullan\u0131n.",
"Tools": "Ara\u00e7lar",
"View": "G\u00f6r\u00fcnt\u00fcle",
"Table": "Tablo",
"Format": "Bi\u00e7im"
});

==> roundcubemail-1.3.4-1-any.pkg.tar.xz: usr/share/webapps/roundcubemail/program/js/tinymce/langs/tr_TR.js <==
tinymce.addI18n('tr_TR',{
"Redo": "Yinele",
"Undo": "Geri Al",
"Cut": "Kes",
"Copy": "Kopyala",
"Paste": "Yap\u0131\u015ft\u0131r",
"Select all": "T\u00fcm\u00fcn\u00fc se\u00e7",
"New document": "Yeni dok\u00fcman",
"Ok": "Tamam",
"Cancel": "\u0130ptal",
"Visual aids": "G\u00f6rsel ara\u00e7lar",
"Bold": "Kal\u0131n",
"Italic": "\u0130talik",
"Underline": "Alt\u0131 \u00e7izili",
"Strikethrough": "\u00dcst\u00fc \u00e7izili",
"Superscript": "\u00dcst simge",
"Subscript": "Alt simge",
"Clear formatting": "Bi\u00e7imi temizle",
"Align left": "Sola hizala",
"Align center": "Ortala",
"Align right": "Sa\u011fa hizala",
"Justify": "\u0130ki yana yasla",
"Bullet list": "S\u0131ras\u0131z liste",
"Numbered list": "S\u0131ral\u0131 liste",
"Decrease indent": "Girintiyi azalt",
"Increase indent": "Girintiyi art\u0131r",
"Close": "Kapat",
"Formats": "Bi\u00e7imler",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Taray\u0131c\u0131n\u0131z panoya direk eri\u015fimi desteklemiyor. L\u00fctfen Ctrl+X\/C\/V klavye k\u0131sayollar\u0131n\u0131 kullan\u0131n.",
"Headers": "Ba\u015fl\u0131klar",
"Header 1": "Ba\u015fl\u0131k 1",
"Header 2": "Ba\u015fl\u0131k 2",
"Header 3": "Ba\u015fl\u0131k 3",
"Header 4": "Ba\u015fl\u0131k 4",
"Header 5": "Ba\u015fl\u0131k 5",
"Header 6": "Ba\u015fl\u0131k 6",
"Headings": "Ba\u015fl\u0131klar",
"Heading 1": "Ba\u015fl\u0131k 1",
"Heading 2": "Ba\u015fl\u0131k 2",
"Heading 3": "Ba\u015fl\u0131k 3",
"Heading 4": "Ba\u015fl\u0131k 4",
"Heading 5": "Ba\u015fl\u0131k 5",
"Heading 6": "Ba\u015fl\u0131k 6",
"Div": "Div",
"Pre": "\u00d6n",
"Code": "Kod",
"Paragraph": "Paragraf",
"Blockquote": "Al\u0131nt\u0131",
"Inline": "Sat\u0131r i\u00e7i",
"Blocks": "Bloklar",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "D\u00fcz metin modunda yap\u0131\u015ft\u0131r. Bu se\u00e7ene\u011fi kapatana kadar i\u00e7erikler d\u00fcz metin olarak yap\u0131\u015ft\u0131r\u0131l\u0131r.",
"Font Family": "Yaz\u0131tipi Ailesi",
"Font Sizes": "Yaz\u0131tipi B\u00fcy\u00fckl\u00fc\u011f\u00fc",
"Class": "S\u0131n\u0131f",
"Browse for an image": "Bir resim aray\u0131n",
"OR": "ya da",
"Drop an image here": "Buraya bir resim koy",
"Upload": "Y\u00fckle",
"Default": "Varsay\u0131lan",
"Circle": "Daire",
"Disc": "Disk",
"Square": "Kare",
"Lower Alpha": "K\u00fc\u00e7\u00fck ABC",
"Lower Greek": "K\u00fc\u00e7\u00fck Yunan alfabesi",
"Lower Roman": "K\u00fc\u00e7\u00fck Roman alfabesi",
"Upper Alpha": "B\u00fcy\u00fck ABC",
"Upper Roman": "B\u00fcy\u00fck Roman alfabesi",
"Anchor": "\u00c7apa",
"Name": "\u0130sim",
"Id": "Id",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Id bir harf ile ba\u015flamal\u0131d\u0131r ve sadece harfleri, rakamlar\u0131, \u00e7izgileri, noktalar\u0131, virg\u00fclleri veya alt \u00e7izgileri i\u00e7ermelidir.",
"You have unsaved changes are you sure you want to navigate away?": "Kaydedilmemi\u015f de\u011fi\u015fiklikler var, sayfadan ayr\u0131lmak istedi\u011finize emin misiniz?",
"Restore last draft": "Son tasla\u011f\u0131 kurtar",
"Special character": "\u00d6zel karakter",
"Source code": "Kaynak kodu",
"Insert\/Edit code sample": "Kod \u00f6rne\u011fini Kaydet\/D\u00fczenle",
"Language": "Dil",
"Color": "Renk",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Soldan sa\u011fa",
"Right to left": "Sa\u011fdan sola",
"Emoticons": "G\u00fcl\u00fcc\u00fckler",
"Document properties": "Dok\u00fcman \u00f6zellikleri",
"Title": "Ba\u015fl\u0131k",
"Keywords": "Anahtar kelimeler",
"Description": "A\u00e7\u0131klama",
"Robots": "Robotlar",
"Author": "Yazar",
"Encoding": "Kodlama",
"Fullscreen": "Tam ekran",
"Action": "Eylem",
"Shortcut": "K\u0131sayol",
"Help": "Yard\u0131m",
"Address": "Adres",
"Focus to menubar": "Men\u00fc \u00e7ubu\u011funa odaklan.",
"Focus to toolbar": "Ara\u00e7 \u00e7ubu\u011funa odaklan.",
"Focus to element path": "Eleman yoluna odaklan",
"Focus to contextual toolbar": "Ba\u011flamsal ara\u00e7 \u00e7ubu\u011funa odaklan",
"Insert link (if link plugin activated)": "Link ekle (Link eklentisi aktif ise)",
"Save (if save plugin activated)": "Kaydet (Kay\u0131t eklentisi aktif ise)",
"Find (if searchreplace plugin activated)": "Bul (SearchReplace eklentisi aktif ise)",
"Plugins installed ({0}):": "Y\u00fckl\u00fc eklenti say\u0131s\u0131 : ({0}):",
"Premium plugins:": "Premium eklentileri",
"Learn more...": "Daha fazla bilgi edinin.",
"You are using {0}": "{0} kullan\u0131yorsun.",
"Horizontal line": "Yatay \u00e7izgi",
"Insert\/edit image": "Resim ekle\/d\u00fczenle",
"Image description": "Resim a\u00e7\u0131klamas\u0131",
"Source": "Kaynak",
"Dimensions": "Boyutlar",
"Constrain proportions": "En - Boy oran\u0131n\u0131 koru",
"General": "Genel",
"Advanced": "Geli\u015fmi\u015f",
"Style": "Stil",
"Vertical space": "Dikey bo\u015fluk",
"Horizontal space": "Yatay bo\u015fluk",
"Border": "\u00c7er\u00e7eve",
"Insert image": "Resim ekle",
"Image": "Resim",
"Image list": "Resim listesi",
"Rotate counterclockwise": "Saat y\u00f6n\u00fcn\u00fcn tersine d\u00f6nd\u00fcr",
"Rotate clockwise": "Saat y\u00f6n\u00fcnde d\u00f6nd\u00fcr",
"Flip vertically": "Dikey \u00e7evir",
"Flip horizontally": "Yatay \u00e7evir",
"Edit image": "G\u00f6r\u00fcnt\u00fcy\u00fc d\u00fczenle",
"Image options": "G\u00f6r\u00fcnt\u00fc se\u00e7enekleri",
"Zoom in": "Yak\u0131nla\u015ft\u0131r",
"Zoom out": "Uzakla\u015ft\u0131r",
"Crop": "Kes",
"Resize": "Yeniden Boyutland\u0131r",
"Orientation": "Y\u00f6n\u00fcn\u00fc Belirle",
"Brightness": "Parlakl\u0131k",
"Sharpen": "Keskinle\u015ftir",
"Contrast": "Kontrast",
"Color levels": "Renk seviyesi",
"Gamma": "Gama",
"Invert": "Tersine \u00e7evir",
"Apply": "Uygula",
"Back": "Geri",
"Insert date\/time": "Tarih \/ Zaman ekle",
"Date\/time": "Tarih\/zaman",
"Insert link": "Ba\u011flant\u0131 ekle",
"Insert\/edit link": "Ba\u011flant\u0131 ekle\/d\u00fczenle",
"Text to display": "G\u00f6r\u00fcnen yaz\u0131",
"Url": "Url",
"Target": "Hedef",
"None": "Hi\u00e7biri",
"New window": "Yeni pencere",
"Remove link": "Ba\u011flant\u0131y\u0131 kald\u0131r",
"Anchors": "\u00c7apalar",
"Link": "Ba\u011flant\u0131",
"Paste or type a link": "Bir ba\u011flant\u0131 yap\u0131\u015ft\u0131r\u0131n yada yaz\u0131n.",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Girdi\u011finiz URL bir eposta adresi gibi g\u00f6z\u00fck\u00fcyor. Gerekli olan mailto: \u00f6nekini eklemek ister misiniz?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Girdi\u011finiz URL bir d\u0131\u015f ba\u011flant\u0131 gibi g\u00f6z\u00fck\u00fcyor. Gerekli olan http:\/\/ \u00f6nekini eklemek ister misiniz?",
"Link list": "Link listesi",
"Insert video": "Video ekle",
"Insert\/edit video": "Video ekle\/d\u00fczenle",
"Insert\/edit media": "Medya ekle\/d\u00fczenle",
"Alternative source": "Alternatif kaynak",
"Poster": "Poster",
"Paste your embed code below:": "Medya g\u00f6mme kodunu buraya yap\u0131\u015ft\u0131r:",
"Embed": "G\u00f6mme",
"Media": "Medya",
"Nonbreaking space": "B\u00f6l\u00fcnemez bo\u015fluk",
"Page break": "Sayfa sonu",
"Paste as text": "Metin olarak yap\u0131\u015ft\u0131r",
"Preview": "\u00d6nizleme",
"Print": "Yazd\u0131r",
"Save": "Kaydet",
"Find": "Bul",
"Replace with": "Bununla de\u011fi\u015ftir",
"Replace": "De\u011fi\u015ftir",
"Replace all": "T\u00fcm\u00fcn\u00fc de\u011fi\u015ftir",
"Prev": "\u00d6nceki",
"Next": "Sonraki",
"Find and replace": "Bul ve de\u011fi\u015ftir",
"Could not find the specified string.": "Herhangi bir sonu\u00e7 bulunamad\u0131.",
"Match case": "B\u00fcy\u00fck \/ K\u00fc\u00e7\u00fck harfe duyarl\u0131",
"Whole words": "Tam s\u00f6zc\u00fckler",
"Spellcheck": "Yaz\u0131m denetimi",
"Ignore": "Yoksay",
"Ignore all": "T\u00fcm\u00fcn\u00fc yoksay",
"Finish": "Bitir",
"Add to Dictionary": "S\u00f6zl\u00fc\u011fe ekle",
"Insert table": "Tablo ekle",
"Table properties": "Tablo \u00f6zellikleri",
"Delete table": "Tabloyu sil",
"Cell": "H\u00fccre",
"Row": "Sat\u0131r",
"Column": "S\u00fctun",
"Cell properties": "H\u00fccre \u00f6zellikleri",
"Merge cells": "H\u00fccreleri birle\u015ftir",
"Split cell": "H\u00fccreleri ay\u0131r",
"Insert row before": "\u00d6ncesine yeni sat\u0131r ekle",
"Insert row after": "Sonras\u0131na yeni sat\u0131r ekle",
"Delete row": "Sat\u0131r\u0131 sil",
"Row properties": "Sat\u0131r \u00f6zellikleri",
"Cut row": "Sat\u0131r\u0131 kes",
"Copy row": "Sat\u0131r\u0131 kopyala",
"Paste row before": "\u00d6ncesine sat\u0131r yap\u0131\u015ft\u0131r",
"Paste row after": "Sonras\u0131na sat\u0131r  yap\u0131\u015ft\u0131r",
"Insert column before": "\u00d6ncesine yeni s\u00fctun ekle",
"Insert column after": "Sonras\u0131na yeni s\u00fctun ekle",
"Delete column": "S\u00fctunu sil",
"Cols": "S\u00fctunlar",
"Rows": "Sat\u0131rlar",
"Width": "Geni\u015flik",
"Height": "Y\u00fckseklik",
"Cell spacing": "H\u00fccre aral\u0131\u011f\u0131",
"Cell padding": "H\u00fccre i\u00e7 bo\u015flu\u011fu",
"Caption": "Ba\u015fl\u0131k",
"Left": "Sol",
"Center": "Orta",
"Right": "Sa\u011f",
"Cell type": "H\u00fccre tipi",
"Scope": "Kapsam",
"Alignment": "Hizalama",
"H Align": "Yatay Hizalama",
"V Align": "Dikey Hizalama",
"Top": "\u00dcst",
"Middle": "Orta",
"Bottom": "Alt",
"Header cell": "Ba\u015fl\u0131k h\u00fccresi",
"Row group": "Sat\u0131r grubu",
"Column group": "S\u00fctun grubu",
"Row type": "Sat\u0131r tipi",
"Header": "Ba\u015fl\u0131k",
"Body": "G\u00f6vde",
"Footer": "Alt",
"Border color": "Kenarl\u0131k Rengi",
"Insert template": "\u015eablon ekle",
"Templates": "\u015eablonlar",
"Template": "Tema",
"Text color": "Yaz\u0131 rengi",
"Background color": "Arkaplan rengi",
"Custom...": "\u00d6zel",
"Custom color": "\u00d6zel Renk",
"No color": "Renk Yok",
"Table of Contents": "\u0130\u00e7indekiler",
"Show blocks": "Bloklar\u0131 g\u00f6r\u00fcnt\u00fcle",
"Show invisible characters": "G\u00f6r\u00fcnmez karakterleri g\u00f6ster",
"Words: {0}": "Kelime: {0}",
"File": "Dosya",
"Edit": "D\u00fczenle",
"Insert": "Ekle",
"View": "G\u00f6r\u00fcnt\u00fcle",
"Format": "Bi\u00e7im",
"Table": "Tablo",
"Tools": "Ara\u00e7lar",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Zengin Metin Alan\u0131. Men\u00fc i\u00e7in ALT-F9 k\u0131sayolunu kullan\u0131n. Ara\u00e7 \u00e7ubu\u011fu i\u00e7in ALT-F10 k\u0131sayolunu kullan\u0131n. Yard\u0131m i\u00e7in ALT-0 k\u0131sayolunu kullan\u0131n."
});
